@@ -12,17 +12,14 @@
 #
 #
 
-import re
-import os
+__version__ = "0.0.6"
 
+import os
 import json
 import cx_Oracle
-
 from tabulate import tabulate
-
 from ipykernel.kernelbase import Kernel
-
-__version__ = "0.0.5"
+from ipykernel.kernelapp import IPKernelApp
 
 DEBUG = 0
 
@@ -40,7 +37,6 @@ def create_dns(cdf):
 def qry2df(qry, constr=None):
     try:
         df = []
-        row = []
         hdr = []
 
         log(str(type(constr)))
@@ -186,7 +182,4 @@ class SQLoKernel(Kernel):
         log("SHUTDOWN")
 
 
-from ipykernel.kernelapp import IPKernelApp
-from sqlo_kernel.kernel import SQLoKernel
-
 IPKernelApp.launch_instance(kernel_class=SQLoKernel)
